$: << 'tests' 

# some tests requiring network access
disabled_tests=[
  'tests/test_idle_connection.rb',
  'tests/test_get_sock_opt.rb',
  'tests/test_set_sock_opt.rb',
]



(Dir['{tests}/**/*.rb']-disabled_tests).each { |f| require f }
